.. Django Snitch documentation master file, created by
   sphinx-quickstart on Wed Feb  5 10:19:59 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=============================
Django Snitch's documentation
=============================

Django app made to integrate generic events that create notifications that
can be sent to users using several backends.

By default, it integrates **push notifications** and **email** to send the
notifications.

.. toctree::
    :maxdepth: 2
    :caption: User Guide

    guide/install
    guide/usage

.. toctree::
    :maxdepth: 2
    :caption: Reference

    reference/settings
